rayoptics.util package
======================

.. automodule:: rayoptics.util
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   rayoptics.util.colors
   rayoptics.util.colour_system
   rayoptics.util.dict2d
   rayoptics.util.line_intersection
   rayoptics.util.misc_math
   rayoptics.util.rgb2mpl
   rayoptics.util.rgbtable
